@@ -20,15 +20,11 @@
 #include "fm.h"
 #include "tagging.h"
 
-#include <MauiKit/Core/utils.h>
-
 #ifdef COMPONENT_SYNCING
-#include <MauiKit/syncing.h>
+#include "syncing.h"
 #endif
 
-#include <QHash>
 #include <QFuture>
-#include <QObject>
 #include <QThread>
 #include <QtConcurrent/QtConcurrentRun>
 #include <QtConcurrent>
@@ -291,14 +287,15 @@ QString FMList::getPathName() const
     return this->pathName;
 }
 
-QUrl FMList::getPath() const
+QString FMList::getPath() const
 {
-    return this->path;
+    return this->path.toString();
 }
 
-void FMList::setPath(const QUrl &path)
+void FMList::setPath(const QString &path)
 {
-    QUrl path_ = QUrl::fromUserInput(path.toString().trimmed());
+    QUrl path_ = QUrl::fromUserInput(path.simplified(), "/", QUrl::AssumeLocalFile).adjusted(QUrl::PreferLocalFile | QUrl::StripTrailingSlash | QUrl::NormalizePathSegments);
+
     if (this->path == path_)
         return;
 
@@ -528,14 +525,17 @@ void FMList::componentComplete()
         }       
     });
    
-    this->setList();
+    if(!this->path.isEmpty() && this->path.isValid())
+    {
+        this->setList();          
+    }
 }
 
 void FMList::search(const QString &query, const QUrl &path, const bool &hidden, const bool &onlyDirs, const QStringList &filters)
 {
     qDebug() << "SEARCHING FOR" << query << path;
 
-    if (!path.isLocalFile()) {
+    if (!path.isLocalFile()) { //if the path is not local then search will not be performed and instead will be filtered
         qWarning() << "URL recived is not a local file. So search will only filter the content" << path;
         this->filterContent(query, path);
         return;
